rekha.BasePlot
==============

.. currentmodule:: rekha

.. autoclass:: BasePlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~BasePlot.add_annotation
      ~BasePlot.get_axes
      ~BasePlot.save
      ~BasePlot.save_all_formats
      ~BasePlot.show
      ~BasePlot.show_legend
      ~BasePlot.update_layout
   
   

   
   
   